@@ -130,7 +130,7 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
     ) -> xr.Dataset:
         """
             A function that gathers the repository files associated with a requested period, and then returns the full
-            weather data that matches both that period as the requested locations from those files, as an Xarray Dataset
+            weather data that matches both that period as the requested locations from those files, as a Xarray Dataset
         Args:
             begin:          A datetime holding the starting moment for the requested period to gather data for
             end:            A datetime holding the ending moment for the requested period to gather data for
@@ -162,6 +162,7 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
         # Load files into datasets, select the requested data and aggregate that into a single dataset
         ds = xr.Dataset()
         for file in file_list:
+            self.logger.debug(f'Processing file: {file}', datetime=datetime.utcnow())
             ds_temp = xr.open_dataset(file).load()
 
             ds_temp = self._filter_dataset_by_coordinates(coordinates, ds_temp)
@@ -173,11 +174,11 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
 
     def load_file(self, file: Path) -> xr.Dataset:
         """
-            A function that loads and returns the full data for a specific repository file as an Xarray Dataset
+            A function that loads and returns the full data for a specific repository file as a Xarray Dataset
         Args:
             file:   The filename (in the Path format by PathLib) specifying the file to load
         Returns:
-            An Xarray Dataset containing all of the weather data held within the specified file.
+            An Xarray Dataset containing all the weather data held within the specified file.
         """
         if file.exists():
             with xr.open_dataset(file) as ds:
@@ -245,7 +246,7 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
             set(
                 [
                     file[
-                    len_filename_until_date: len_filename_until_date + self.file_identifier_length
+                        len_filename_until_date: len_filename_until_date + self.file_identifier_length
                     ]
                     for file in file_list
                 ]
@@ -337,4 +338,4 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
     @abstractmethod
     def get_grid_coordinates(self, coordinates: List[GeoPosition]) -> List[GeoPosition]:
         self.logger.error("This method is abstract and should be overridden.")
-        raise NotImplementedError()
\ No newline at end of file
+        raise NotImplementedError()
